==> huaweicloudsdklts-3.0.50-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/list_log_stream_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListLogStreamResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'log_streams': 'list[LogStream]'
    }

    attribute_map = {
        'log_streams': 'log_streams'
    }

    def __init__(self, log_streams=None):
        """ListLogStreamResponse - a model defined in huaweicloud sdk"""
        
        super(ListLogStreamResponse, self).__init__()

        self._log_streams = None
        self.discriminator = None

        if log_streams is not None:
            self.log_streams = log_streams

    @property
    def log_streams(self):
        """Gets the log_streams of this ListLogStreamResponse.

        日志组数组。

        :return: The log_streams of this ListLogStreamResponse.
        :rtype: list[LogStream]
        """
        return self._log_streams

    @log_streams.setter
    def log_streams(self, log_streams):
        """Sets the log_streams of this ListLogStreamResponse.

        日志组数组。

        :param log_streams: The log_streams of this ListLogStreamResponse.
        :type: list[LogStream]
        """
        self._log_streams = log_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLogStreamResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklts-3.0.52-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/list_log_stream_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListLogStreamResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'log_streams': 'list[LogStream]'
    }

    attribute_map = {
        'log_streams': 'log_streams'
    }

    def __init__(self, log_streams=None):
        """ListLogStreamResponse - a model defined in huaweicloud sdk"""
        
        super(ListLogStreamResponse, self).__init__()

        self._log_streams = None
        self.discriminator = None

        if log_streams is not None:
            self.log_streams = log_streams

    @property
    def log_streams(self):
        """Gets the log_streams of this ListLogStreamResponse.

        日志组数组。

        :return: The log_streams of this ListLogStreamResponse.
        :rtype: list[LogStream]
        """
        return self._log_streams

    @log_streams.setter
    def log_streams(self, log_streams):
        """Sets the log_streams of this ListLogStreamResponse.

        日志组数组。

        :param log_streams: The log_streams of this ListLogStreamResponse.
        :type: list[LogStream]
        """
        self._log_streams = log_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLogStreamResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
